summaryrefslogtreecommitdiff
path: root/nuttx/examples/nx/nx_internal.h
diff options
context:
space:
mode:
authorpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2008-12-06 13:45:05 +0000
committerpatacongo <patacongo@42af7a65-404d-4744-a932-0658087f49c3>2008-12-06 13:45:05 +0000
commit3df1d5fd1bbb583c3bd44a24939e49fa0d52c161 (patch)
tree885d99188138df23399a9c3238bffc75c5677802 /nuttx/examples/nx/nx_internal.h
parent577e371190dfd26667149dbbf66d49c7c1374243 (diff)
downloadpx4-nuttx-3df1d5fd1bbb583c3bd44a24939e49fa0d52c161.tar.gz
px4-nuttx-3df1d5fd1bbb583c3bd44a24939e49fa0d52c161.tar.bz2
px4-nuttx-3df1d5fd1bbb583c3bd44a24939e49fa0d52c161.zip
Allocate smaller buffers for glyphs
git-svn-id: svn://svn.code.sf.net/p/nuttx/code/trunk@1422 42af7a65-404d-4744-a932-0658087f49c3
Diffstat (limited to 'nuttx/examples/nx/nx_internal.h')
-rw-r--r--nuttx/examples/nx/nx_internal.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/nuttx/examples/nx/nx_internal.h b/nuttx/examples/nx/nx_internal.h
index 7e1594d68..7f7c5642a 100644
--- a/nuttx/examples/nx/nx_internal.h
+++ b/nuttx/examples/nx/nx_internal.h
@@ -208,8 +208,9 @@ enum exitcode_e
struct nxeg_glyph_s
{
ubyte code; /* Character code */
- ubyte width; /* Visible width of this glyph */
- ubyte stride; /* Width of the glyph row in bytes */
+ ubyte height; /* Height of this glyph (in rows) */
+ ubyte width; /* Width of this glyph (in pixels) */
+ ubyte stride; /* Width of the glyph row (in bytes) */
FAR ubyte *bitmap; /* Allocated bitmap memory */
};
@@ -231,6 +232,7 @@ struct nxeg_state_s
#ifdef CONFIG_NX_KBD
ubyte height; /* Max height of a font in pixels */
ubyte width; /* Max width of a font in pixels */
+ ubyte spwidth; /* The width of a space */
ubyte nchars; /* Number of KBD chars received */
ubyte nglyphs; /* Number of glyphs cached */